==> 0.0.9.tar.gz: lib/API/PIA_API_Background.dart <==

import 'dart:convert';
import 'dart:io';
import 'package:dio/dio.dart';
import 'package:pia_framework_base/Popup/PIA_Alert.dart';
import 'package:pia_framework_base/Variable/PIA_Global.dart';
import 'package:pia_framework_base/Lang/PIA_Lang.dart';

// #docregion print-state
class PIA_API_Background {
  static CancelToken token = new CancelToken();
  static Dio dio = new Dio();

  static Post(String url,Map<String,String> post,PIA_API_CallBack callback) async {
    token = new CancelToken();
    Dio dio = new Dio();
    dio.options.connectTimeout = connectTimeout;
    dio.options.receiveTimeout = receiveTimeout;

    Map<String, dynamic> fordata = Map<String, dynamic>();
    if (post != null) {
      post.forEach((String key, String value) {
        fordata[key] = value;
      });
    }

    var formData = new FormData.from(fordata);

    Response response = await dio.post(
      url,
      data: formData,
      cancelToken: token,
      onSendProgress: (int sent, int total) {
        print(" $sent $total");
      },
    ).catchError((err) {
      token = null;
      DioError error = err;
      if(error.type == DioErrorType.CANCEL) {
        print("API Cancel ");
        return;
      }

      print("Catch Error " + error.message);
      print("Error type ");
      print(error.type);

       if (error.type == DioErrorType.RESPONSE) {
         print("BackEnd Connect Error : " + url);
        }

        if (error.type == DioErrorType.CONNECT_TIMEOUT) {
          print("BackEnd API Connect No Network");
        }

        if (error.type == DioErrorType.DEFAULT) {
          print("BackEnd Error Result " + error.message);
        }

        if (error.type == DioErrorType.RECEIVE_TIMEOUT) {
          print("BackEnd API Connect  TimeOut"); }

      if (callback != null) {
        callback.API_Error(error.type);
        }
       return;
    });

    token = null;
    if (response != null && response.statusCode == 200) {
      print(response.toString());
      print("status :" + response.statusCode.toString());

      var js = jsonDecode(response.toString());
      if (js["status"] == 0 && js["err_message"]
          .toString()
          .isNotEmpty) {
        print("API Return Status 0 ");
      }
      else {
        if (callback != null) {
          callback.API_Success(js["sdata"], js["data"]);
        }
      }
    }
  }

  static Stop() {
    if (token != null) {
      token.cancel();
      token = null;
    }
  }

  static Upload(String url,Map<String,String> post, Map<String,File> upload,PIA_API_CallBack callback) async {
    token = new CancelToken();
    Dio dio = new Dio();
    dio.options.connectTimeout = connectTimeout;

    Map<String, dynamic> fordata = Map<String, dynamic>();
    if (post != null) {
      post.forEach((String key, String value) {
        fordata[key] = value;
      });
    }

    upload.forEach((String key, File file) {
      fordata[key] = new UploadFileInfo(file, file.path);
    });

    var formData = new FormData.from(fordata);

    Response response = await dio.post(
      url,
      data: formData,
      cancelToken: token,
      onSendProgress: (int sent, int total) {
        if(callback != null)
          {  callback.API_Upload_prodcess(sent, total); }
      },
    ).catchError((err) {
      token = null;
      DioError error = err;

      if(error.type == DioErrorType.CANCEL) {
        print("API Cancel ");
        return;
      }

      print("Catch Error " + error.message);
      print("Error type ");
      print(error.type);

      if (error.type == DioErrorType.RESPONSE) {
        print("BackEnd Connect Error : " + url);
      }

      if (error.type == DioErrorType.CONNECT_TIMEOUT) {
        print("BackEnd API Connect No Network");
      }

      if (error.type == DioErrorType.DEFAULT) {
        print("BackEnd Error Result " + error.message);
      }

      if (error.type == DioErrorType.RECEIVE_TIMEOUT) {
        print("BackEnd API Connect  TimeOut"); }

      if (callback != null) {
        callback.API_Error(error.type);
      }
    });

    token = null;
    if (response != null && response.statusCode == 200) {
      print(response.toString());
      print("status :" + response.statusCode.toString());

      var js = jsonDecode(response.toString());
      if (js["status"] == 0 && js["err_message"]
          .toString()
          .isNotEmpty) {
        print("API Return Status 0 ");
      }
      else {
        if (callback != null) {
          callback.API_Success(js["sdata"], js["data"]);
        }
      }
    }
  }
}

==> 1.15.2.tar.gz: lib/API/PIA_API_Background.dart <==

import 'dart:convert';
import 'dart:io';
import 'package:dio/dio.dart';
import 'package:pia_framework_base/Variable/PIA_Global.dart';


// #docregion print-state
class PIA_API_Background {
  static CancelToken token = new CancelToken();
  static Dio dio = new Dio();

  static Post(String url,Map<String,String> post,PIA_API_CallBack callback) async {
    token = new CancelToken();
    Dio dio = new Dio();
    dio.options.connectTimeout = connectTimeout;
    dio.options.receiveTimeout = receiveTimeout;

    Map<String, dynamic> fordata = Map<String, dynamic>();
    if (post != null) {
      post.forEach((String key, String value) {
        fordata[key] = value;
      });
    }

    var formData = new FormData.fromMap(fordata);

    Response response = await dio.post(
      url,
      data: formData,
      cancelToken: token,
      onSendProgress: (int sent, int total) {
        print(" $sent $total");
      },
    ).catchError((err) {
      token = null;
      DioError error = err;
      if(error.type == DioErrorType.CANCEL) {
        print("API Cancel ");
        return;
      }

      print("Catch Error " + error.message);
      print("Error type ");
      print(error.type);

       if (error.type == DioErrorType.RESPONSE) {
         print("BackEnd Connect Error : " + url);
        }

        if (error.type == DioErrorType.CONNECT_TIMEOUT) {
          print("BackEnd API Connect No Network");
        }

        if (error.type == DioErrorType.DEFAULT) {
          print("BackEnd Error Result " + error.message);
        }

        if (error.type == DioErrorType.RECEIVE_TIMEOUT) {
          print("BackEnd API Connect  TimeOut"); }

      if (callback != null) {
        callback.API_Error(error.type);
        }
       return;
    });

    token = null;
    if (response != null && response.statusCode == 200) {
      print(response.toString());
      print("status :" + response.statusCode.toString());

      var js = jsonDecode(response.toString());
      if (js["status"] == 0 && js["err_message"]
          .toString()
          .isNotEmpty) {
        print("API Return Status 0 ");
      }
      else {
        if (callback != null) {
          callback.API_Success(js["sdata"], js["data"]);
        }
      }
    }
  }

  static Stop() {
    if (token != null) {
      token.cancel();
      token = null;
    }
  }

  static Upload(String url,Map<String,String> post, Map<String,File> upload,PIA_API_CallBack callback) async {
    token = new CancelToken();
    Dio dio = new Dio();
    dio.options.connectTimeout = connectTimeout;

    Map<String, dynamic> fordata = Map<String, dynamic>();
    if (post != null) {
      post.forEach((String key, String value) {
        fordata[key] = value;
      });
    }

    upload.forEach((String key, File file) async {
      fordata[key] = await MultipartFile.fromFile(file.path, filename: key);
    });

    var formData = new FormData.fromMap(fordata);

    Response response = await dio.post(
      url,
      data: formData,
      cancelToken: token,
      onSendProgress: (int sent, int total) {
        if(callback != null)
          {  callback.API_Upload_prodcess(sent, total); }
      },
    ).catchError((err) {
      token = null;
      DioError error = err;

      if(error.type == DioErrorType.CANCEL) {
        print("API Cancel ");
        return;
      }

      print("Catch Error " + error.message);
      print("Error type ");
      print(error.type);

      if (error.type == DioErrorType.RESPONSE) {
        print("BackEnd Connect Error : " + url);
      }

      if (error.type == DioErrorType.CONNECT_TIMEOUT) {
        print("BackEnd API Connect No Network");
      }

      if (error.type == DioErrorType.DEFAULT) {
        print("BackEnd Error Result " + error.message);
      }

      if (error.type == DioErrorType.RECEIVE_TIMEOUT) {
        print("BackEnd API Connect  TimeOut"); }

      if (callback != null) {
        callback.API_Error(error.type);
      }
    });

    token = null;
    if (response != null && response.statusCode == 200) {
      print(response.toString());
      print("status :" + response.statusCode.toString());

      var js = jsonDecode(response.toString());
      if (js["status"] == 0 && js["err_message"]
          .toString()
          .isNotEmpty) {
        print("API Return Status 0 ");
      }
      else {
        if (callback != null) {
          callback.API_Success(js["sdata"], js["data"]);
        }
      }
    }
  }
}
